@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2008-2019 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2008-2020 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -300,7 +300,7 @@ $def_off{0} = {
                '-03:06:28' => 'America/Sao_Paulo',
                '-03:12:48' => 'America/Araguaina',
                '-03:13:56' => 'America/Belem',
-               '-03:26:56' => 'America/Godthab',
+               '-03:26:56' => 'America/Nuuk',
                '-03:29:20' => 'America/Cayenne',
                '-03:30:00' => 'America/St_Johns',
                '-03:30:52' => 'America/St_Johns',
@@ -503,7 +503,7 @@ $def_off{1} = {
                '+14:00:00' => 'Pacific/Apia',
                '-01:00:00' => 'America/Noronha',
                '-01:30:00' => 'America/St_Johns',
-               '-02:00:00' => 'America/Godthab',
+               '-02:00:00' => 'America/Nuuk',
                '-02:30:00' => 'America/St_Johns',
                '-02:30:52' => 'America/St_Johns',
                '-03:00:00' => 'America/Halifax',
